# Generated from aspida.g4 by ANTLR 4.8
from antlr4 import *
from egida.dsl.parser.aspida_parser import AspidaParser

# This class defines a complete listener for a parse tree produced by aspidaParser.
class AspidaListener(ParseTreeListener):

    # Enter a parse tree produced by aspidaParser#program.
    def enterProgram(self, ctx:AspidaParser.ProgramContext):
        pass

    # Exit a parse tree produced by aspidaParser#program.
    def exitProgram(self, ctx:AspidaParser.ProgramContext):
        pass


    # Enter a parse tree produced by aspidaParser#main.
    def enterMain(self, ctx:AspidaParser.MainContext):
        pass

    # Exit a parse tree produced by aspidaParser#main.
    def exitMain(self, ctx:AspidaParser.MainContext):
        pass


    # Enter a parse tree produced by aspidaParser#hosts.
    def enterHosts(self, ctx:AspidaParser.HostsContext):
        pass

    # Exit a parse tree produced by aspidaParser#hosts.
    def exitHosts(self, ctx:AspidaParser.HostsContext):
        pass


    # Enter a parse tree produced by aspidaParser#tasks.
    def enterTasks(self, ctx:AspidaParser.TasksContext):
        pass

    # Exit a parse tree produced by aspidaParser#tasks.
    def exitTasks(self, ctx:AspidaParser.TasksContext):
        pass


    # Enter a parse tree produced by aspidaParser#variables.
    def enterVariables(self, ctx:AspidaParser.VariablesContext):
        pass

    # Exit a parse tree produced by aspidaParser#variables.
    def exitVariables(self, ctx:AspidaParser.VariablesContext):
        pass


    # Enter a parse tree produced by aspidaParser#main_content.
    def enterMain_content(self, ctx:AspidaParser.Main_contentContext):
        pass

    # Exit a parse tree produced by aspidaParser#main_content.
    def exitMain_content(self, ctx:AspidaParser.Main_contentContext):
        pass


    # Enter a parse tree produced by aspidaParser#main_prop.
    def enterMain_prop(self, ctx:AspidaParser.Main_propContext):
        pass

    # Exit a parse tree produced by aspidaParser#main_prop.
    def exitMain_prop(self, ctx:AspidaParser.Main_propContext):
        pass


    # Enter a parse tree produced by aspidaParser#name.
    def enterName(self, ctx:AspidaParser.NameContext):
        pass

    # Exit a parse tree produced by aspidaParser#name.
    def exitName(self, ctx:AspidaParser.NameContext):
        pass


    # Enter a parse tree produced by aspidaParser#connection.
    def enterConnection(self, ctx:AspidaParser.ConnectionContext):
        pass

    # Exit a parse tree produced by aspidaParser#connection.
    def exitConnection(self, ctx:AspidaParser.ConnectionContext):
        pass


    # Enter a parse tree produced by aspidaParser#description.
    def enterDescription(self, ctx:AspidaParser.DescriptionContext):
        pass

    # Exit a parse tree produced by aspidaParser#description.
    def exitDescription(self, ctx:AspidaParser.DescriptionContext):
        pass


    # Enter a parse tree produced by aspidaParser#hosts_list.
    def enterHosts_list(self, ctx:AspidaParser.Hosts_listContext):
        pass

    # Exit a parse tree produced by aspidaParser#hosts_list.
    def exitHosts_list(self, ctx:AspidaParser.Hosts_listContext):
        pass


    # Enter a parse tree produced by aspidaParser#host.
    def enterHost(self, ctx:AspidaParser.HostContext):
        pass

    # Exit a parse tree produced by aspidaParser#host.
    def exitHost(self, ctx:AspidaParser.HostContext):
        pass


    # Enter a parse tree produced by aspidaParser#tasks_content.
    def enterTasks_content(self, ctx:AspidaParser.Tasks_contentContext):
        pass

    # Exit a parse tree produced by aspidaParser#tasks_content.
    def exitTasks_content(self, ctx:AspidaParser.Tasks_contentContext):
        pass


    # Enter a parse tree produced by aspidaParser#tasks_prop.
    def enterTasks_prop(self, ctx:AspidaParser.Tasks_propContext):
        pass

    # Exit a parse tree produced by aspidaParser#tasks_prop.
    def exitTasks_prop(self, ctx:AspidaParser.Tasks_propContext):
        pass


    # Enter a parse tree produced by aspidaParser#sections.
    def enterSections(self, ctx:AspidaParser.SectionsContext):
        pass

    # Exit a parse tree produced by aspidaParser#sections.
    def exitSections(self, ctx:AspidaParser.SectionsContext):
        pass


    # Enter a parse tree produced by aspidaParser#points.
    def enterPoints(self, ctx:AspidaParser.PointsContext):
        pass

    # Exit a parse tree produced by aspidaParser#points.
    def exitPoints(self, ctx:AspidaParser.PointsContext):
        pass


    # Enter a parse tree produced by aspidaParser#controls.
    def enterControls(self, ctx:AspidaParser.ControlsContext):
        pass

    # Exit a parse tree produced by aspidaParser#controls.
    def exitControls(self, ctx:AspidaParser.ControlsContext):
        pass


    # Enter a parse tree produced by aspidaParser#exclusions.
    def enterExclusions(self, ctx:AspidaParser.ExclusionsContext):
        pass

    # Exit a parse tree produced by aspidaParser#exclusions.
    def exitExclusions(self, ctx:AspidaParser.ExclusionsContext):
        pass


    # Enter a parse tree produced by aspidaParser#vars_content.
    def enterVars_content(self, ctx:AspidaParser.Vars_contentContext):
        pass

    # Exit a parse tree produced by aspidaParser#vars_content.
    def exitVars_content(self, ctx:AspidaParser.Vars_contentContext):
        pass


    # Enter a parse tree produced by aspidaParser#vars_prop.
    def enterVars_prop(self, ctx:AspidaParser.Vars_propContext):
        pass

    # Exit a parse tree produced by aspidaParser#vars_prop.
    def exitVars_prop(self, ctx:AspidaParser.Vars_propContext):
        pass


    # Enter a parse tree produced by aspidaParser#value.
    def enterValue(self, ctx:AspidaParser.ValueContext):
        pass

    # Exit a parse tree produced by aspidaParser#value.
    def exitValue(self, ctx:AspidaParser.ValueContext):
        pass


    # Enter a parse tree produced by aspidaParser#str_array.
    def enterStr_array(self, ctx:AspidaParser.Str_arrayContext):
        pass

    # Exit a parse tree produced by aspidaParser#str_array.
    def exitStr_array(self, ctx:AspidaParser.Str_arrayContext):
        pass


    # Enter a parse tree produced by aspidaParser#cadena.
    def enterCadena(self, ctx:AspidaParser.CadenaContext):
        pass

    # Exit a parse tree produced by aspidaParser#cadena.
    def exitCadena(self, ctx:AspidaParser.CadenaContext):
        pass


    # Enter a parse tree produced by aspidaParser#array.
    def enterArray(self, ctx:AspidaParser.ArrayContext):
        pass

    # Exit a parse tree produced by aspidaParser#array.
    def exitArray(self, ctx:AspidaParser.ArrayContext):
        pass


    # Enter a parse tree produced by aspidaParser#ip_v4.
    def enterIp_v4(self, ctx:AspidaParser.Ip_v4Context):
        pass

    # Exit a parse tree produced by aspidaParser#ip_v4.
    def exitIp_v4(self, ctx:AspidaParser.Ip_v4Context):
        pass


    # Enter a parse tree produced by aspidaParser#single_ip.
    def enterSingle_ip(self, ctx:AspidaParser.Single_ipContext):
        pass

    # Exit a parse tree produced by aspidaParser#single_ip.
    def exitSingle_ip(self, ctx:AspidaParser.Single_ipContext):
        pass


    # Enter a parse tree produced by aspidaParser#ip_range.
    def enterIp_range(self, ctx:AspidaParser.Ip_rangeContext):
        pass

    # Exit a parse tree produced by aspidaParser#ip_range.
    def exitIp_range(self, ctx:AspidaParser.Ip_rangeContext):
        pass


    # Enter a parse tree produced by aspidaParser#ip_v6.
    def enterIp_v6(self, ctx:AspidaParser.Ip_v6Context):
        pass

    # Exit a parse tree produced by aspidaParser#ip_v6.
    def exitIp_v6(self, ctx:AspidaParser.Ip_v6Context):
        pass


    # Enter a parse tree produced by aspidaParser#h16.
    def enterH16(self, ctx:AspidaParser.H16Context):
        pass

    # Exit a parse tree produced by aspidaParser#h16.
    def exitH16(self, ctx:AspidaParser.H16Context):
        pass


    # Enter a parse tree produced by aspidaParser#ls32.
    def enterLs32(self, ctx:AspidaParser.Ls32Context):
        pass

    # Exit a parse tree produced by aspidaParser#ls32.
    def exitLs32(self, ctx:AspidaParser.Ls32Context):
        pass


    # Enter a parse tree produced by aspidaParser#hexdigit.
    def enterHexdigit(self, ctx:AspidaParser.HexdigitContext):
        pass

    # Exit a parse tree produced by aspidaParser#hexdigit.
    def exitHexdigit(self, ctx:AspidaParser.HexdigitContext):
        pass



del AspidaParser


import os

from egida.common.command import run_command
from egida.common.file_manager import FileManager


class Playbook:

    def __init__(self, name, tags=None):
        if tags is None:
            tags = []
        self.name = name
        self.tags = tags

    def get_str_tags(self):
        if len(self.tags) == 0:
            return ""
        else:
            tags_str = ' --tags "' + ','.join(self.tags) + '"'
            return tags_str

    def run(self):
        fm = FileManager()
        fm.create_vars_and_hosts()
        cur_path = os.path.abspath(os.path.dirname(__file__))
        path = os.path.join(cur_path, "playbook-custom.yml")
        command_str = 'ansible-playbook ' + path + self.get_str_tags()
        run_command(command_str)


    def run_aspida(self, aspida):
        pass


import os
from setuptools import setup, find_packages
from egida import egida

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name = "egida",
    version = "1.0.1",
    author = "Antonio Paya Gonzalez",
    author_email = "antoniopaya@outlook.com",
    description = "Egida Project Main",
    long_description=long_description,
    long_description_content_type='text/markdown',
    license = "MIT",
    url = "https://antonioalfa22.github.io/egida/",
    download_url = "https://github.com/antonioalfa22/egida/releases/tag/1.0.1",
    packages=find_packages(include=['egida', 'egida.*']),
    install_requires=[
        'antlr4-python3-runtime==4.8',
        'certifi==2020.4.5.1',
        'cffi==1.14.0',
        'chardet==3.0.4',
        'console-menu==0.6.0',
        'cryptography==2.9.2',
        'idna==2.9',
        'Jinja2==2.11.2',
        'MarkupSafe==1.1.1',
        'prompt-toolkit==1.0.14',
        'pycparser==2.20',
        'Pygments==2.6.1',
        'PyInquirer==1.0.3',
        'PyYAML==5.3.1',
        'regex==2020.4.4',
        'requests==2.23.0',
        'six==1.14.0',
        'urllib3==1.25.9',
        'wcwidth==0.1.9',
    ],
    entry_points = {
        'console_scripts' : ['egida = egida.egida:main']
    },
    package_data={'egida': [
        'common/hosts',
        'common/playbook.yml.j2',
        'common/playbook-custom.yml',
        'custom/vars_template.yml'
    ]}
)


from consolemenu import *
from consolemenu.items import *
from consolemenu.format import *
from consolemenu.menu_component import Dimension

from egida.menu.cis import CISConsole


class Console:

    def show_menu(self):
        thin = Dimension(width=100, height=100)
        menu_format = MenuFormatBuilder(max_dimension=thin)
        menu_format.set_border_style_type(MenuBorderStyleType.DOUBLE_LINE_OUTER_LIGHT_INNER_BORDER)

        menu_format.set_title_align('center')
        menu_format.set_prologue_text_align('center')
        menu_format.show_prologue_bottom_border(True)

        # Create the root menu
        menu = ConsoleMenu("EGIDA", prologue_text="Subtitle")
        menu.formatter = menu_format
        self.set_menu_items(menu)

        # Show the menu
        menu.show(True)

    def set_menu_items(self, menu):
        menu.append_item(FunctionItem("CIS Benchmarks", self.action, args=['cis_benchmarks']))
        menu.append_item(FunctionItem("LAMP", self.action, args=['lamp']))
        menu.append_item(FunctionItem("LEMP", self.action, args=['lemp']))

    def action(self, name):
        exec('self.{}()'.format(name))

    def cis_benchmarks(self):
        CISConsole()

    def lamp(self):
        print("Lamp")
        Screen().input('Press [Enter] to continue')

    def lemp(self):
        print("Lemp")
        Screen().input('Press [Enter] to continue')



import argparse

from egida.menu import menu
from egida.dsl import compile
from egida.config import config
from egida.info import info


# ========  Mode  ===================
def invalid_args():
    print("EGIDA Mode invalid -> [menu | compile | console | info]")


# ========  Main  ===================
def parse_args():
    parser = argparse.ArgumentParser(description='EGIDA')
    parser.add_argument("mode", help="EGIDA Mode [menu | compile | config | info]")
    parser.add_argument("--file", help="ASPIDA file")
    parser.add_argument("-g", "--group", help="Host group")
    parser.add_argument('-H','--hosts', nargs='+', help='List of hosts, ej: 192.128.2.1 localhost 129.1.1.1')
    parser.add_argument('-a', '--audit', help='Audit hosts with lynis', default=False, action='store_true')
    args = parser.parse_args()
    return args


def main() -> None:
    args = parse_args()
    if args.mode == "menu":
        menu()
    elif args.mode == "compile":
        compile(args)
    elif args.mode == "config":
        config(args)
    elif args.mode == "info":
        info(args)
    else:
        invalid_args()







class Aspida:

    def __init__(self,
                 name,
                 description,
                 connection,
                 hosts = [],
                 points = [],
                 sections = [],
                 controls = [],
                 exclusions = [],
                 vars = {}):
        self.name = name
        self.description = description
        self.connection = connection
        self.hosts = hosts
        self.points = points
        self.sections = sections
        self.controls = controls
        self.exclusions = exclusions
        self.vars = vars


    def run_playbook(self):
        pass
